# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKImageIntensityPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkExpNegativeImageFilterPython
else:
    import _itkExpNegativeImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkInPlaceImageFilterAPython
import itk.itkImageToImageFilterAPython
import itk.itkImageToImageFilterCommonPython
import itk.pyBasePython
import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkPointPython
import itk.itkImagePython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageToImageFilterBPython

def itkExpNegativeImageFilterIF2IF2_Superclass_New():
    return itkExpNegativeImageFilterIF2IF2_Superclass.New()

class itkExpNegativeImageFilterIF2IF2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF2IF2):
    r"""Proxy of C++ itkExpNegativeImageFilterIF2IF2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkExpNegativeImageFilterIF2IF2_Superclass_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF2IF2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkExpNegativeImageFilterIF2IF2_Superclass_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF2IF2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::ExpNegative< float,float >
        GetFunctor(self) -> itk::Functor::ExpNegative< float,float > const &
        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF2IF2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::ExpNegative< float,float > const &

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF2IF2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkExpNegativeImageFilterPython.delete_itkExpNegativeImageFilterIF2IF2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkExpNegativeImageFilterIF2IF2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF2IF2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkExpNegativeImageFilterIF2IF2_Superclass

        Create a new object of the class itkExpNegativeImageFilterIF2IF2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkExpNegativeImageFilterIF2IF2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkExpNegativeImageFilterIF2IF2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkExpNegativeImageFilterIF2IF2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkExpNegativeImageFilterIF2IF2_Superclass in _itkExpNegativeImageFilterPython:
_itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF2IF2_Superclass_swigregister(itkExpNegativeImageFilterIF2IF2_Superclass)

def itkExpNegativeImageFilterIF3IF3_Superclass_New():
    return itkExpNegativeImageFilterIF3IF3_Superclass.New()

class itkExpNegativeImageFilterIF3IF3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF3IF3):
    r"""Proxy of C++ itkExpNegativeImageFilterIF3IF3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkExpNegativeImageFilterIF3IF3_Superclass_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF3IF3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkExpNegativeImageFilterIF3IF3_Superclass_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF3IF3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::ExpNegative< float,float >
        GetFunctor(self) -> itk::Functor::ExpNegative< float,float > const &
        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF3IF3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::ExpNegative< float,float > const &

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF3IF3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkExpNegativeImageFilterPython.delete_itkExpNegativeImageFilterIF3IF3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkExpNegativeImageFilterIF3IF3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF3IF3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkExpNegativeImageFilterIF3IF3_Superclass

        Create a new object of the class itkExpNegativeImageFilterIF3IF3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkExpNegativeImageFilterIF3IF3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkExpNegativeImageFilterIF3IF3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkExpNegativeImageFilterIF3IF3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkExpNegativeImageFilterIF3IF3_Superclass in _itkExpNegativeImageFilterPython:
_itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF3IF3_Superclass_swigregister(itkExpNegativeImageFilterIF3IF3_Superclass)

def itkExpNegativeImageFilterISS2ISS2_Superclass_New():
    return itkExpNegativeImageFilterISS2ISS2_Superclass.New()

class itkExpNegativeImageFilterISS2ISS2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS2ISS2):
    r"""Proxy of C++ itkExpNegativeImageFilterISS2ISS2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkExpNegativeImageFilterISS2ISS2_Superclass_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS2ISS2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkExpNegativeImageFilterISS2ISS2_Superclass_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS2ISS2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::ExpNegative< short,short >
        GetFunctor(self) -> itk::Functor::ExpNegative< short,short > const &
        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS2ISS2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::ExpNegative< short,short > const &

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS2ISS2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkExpNegativeImageFilterPython.delete_itkExpNegativeImageFilterISS2ISS2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkExpNegativeImageFilterISS2ISS2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS2ISS2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkExpNegativeImageFilterISS2ISS2_Superclass

        Create a new object of the class itkExpNegativeImageFilterISS2ISS2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkExpNegativeImageFilterISS2ISS2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkExpNegativeImageFilterISS2ISS2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkExpNegativeImageFilterISS2ISS2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkExpNegativeImageFilterISS2ISS2_Superclass in _itkExpNegativeImageFilterPython:
_itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS2ISS2_Superclass_swigregister(itkExpNegativeImageFilterISS2ISS2_Superclass)

def itkExpNegativeImageFilterISS3ISS3_Superclass_New():
    return itkExpNegativeImageFilterISS3ISS3_Superclass.New()

class itkExpNegativeImageFilterISS3ISS3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS3ISS3):
    r"""Proxy of C++ itkExpNegativeImageFilterISS3ISS3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkExpNegativeImageFilterISS3ISS3_Superclass_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS3ISS3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkExpNegativeImageFilterISS3ISS3_Superclass_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS3ISS3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::ExpNegative< short,short >
        GetFunctor(self) -> itk::Functor::ExpNegative< short,short > const &
        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS3ISS3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::ExpNegative< short,short > const &

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS3ISS3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkExpNegativeImageFilterPython.delete_itkExpNegativeImageFilterISS3ISS3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkExpNegativeImageFilterISS3ISS3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS3ISS3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkExpNegativeImageFilterISS3ISS3_Superclass

        Create a new object of the class itkExpNegativeImageFilterISS3ISS3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkExpNegativeImageFilterISS3ISS3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkExpNegativeImageFilterISS3ISS3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkExpNegativeImageFilterISS3ISS3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkExpNegativeImageFilterISS3ISS3_Superclass in _itkExpNegativeImageFilterPython:
_itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS3ISS3_Superclass_swigregister(itkExpNegativeImageFilterISS3ISS3_Superclass)

def itkExpNegativeImageFilterIUC2IUC2_Superclass_New():
    return itkExpNegativeImageFilterIUC2IUC2_Superclass.New()

class itkExpNegativeImageFilterIUC2IUC2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC2IUC2):
    r"""Proxy of C++ itkExpNegativeImageFilterIUC2IUC2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkExpNegativeImageFilterIUC2IUC2_Superclass_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC2IUC2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkExpNegativeImageFilterIUC2IUC2_Superclass_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC2IUC2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::ExpNegative< unsigned char,unsigned char >
        GetFunctor(self) -> itk::Functor::ExpNegative< unsigned char,unsigned char > const &
        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC2IUC2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::ExpNegative< unsigned char,unsigned char > const &

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC2IUC2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkExpNegativeImageFilterPython.delete_itkExpNegativeImageFilterIUC2IUC2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkExpNegativeImageFilterIUC2IUC2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC2IUC2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkExpNegativeImageFilterIUC2IUC2_Superclass

        Create a new object of the class itkExpNegativeImageFilterIUC2IUC2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkExpNegativeImageFilterIUC2IUC2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkExpNegativeImageFilterIUC2IUC2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkExpNegativeImageFilterIUC2IUC2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkExpNegativeImageFilterIUC2IUC2_Superclass in _itkExpNegativeImageFilterPython:
_itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC2IUC2_Superclass_swigregister(itkExpNegativeImageFilterIUC2IUC2_Superclass)

def itkExpNegativeImageFilterIUC3IUC3_Superclass_New():
    return itkExpNegativeImageFilterIUC3IUC3_Superclass.New()

class itkExpNegativeImageFilterIUC3IUC3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC3IUC3):
    r"""Proxy of C++ itkExpNegativeImageFilterIUC3IUC3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkExpNegativeImageFilterIUC3IUC3_Superclass_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC3IUC3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkExpNegativeImageFilterIUC3IUC3_Superclass_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC3IUC3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::ExpNegative< unsigned char,unsigned char >
        GetFunctor(self) -> itk::Functor::ExpNegative< unsigned char,unsigned char > const &
        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC3IUC3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::ExpNegative< unsigned char,unsigned char > const &

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC3IUC3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkExpNegativeImageFilterPython.delete_itkExpNegativeImageFilterIUC3IUC3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkExpNegativeImageFilterIUC3IUC3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC3IUC3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkExpNegativeImageFilterIUC3IUC3_Superclass

        Create a new object of the class itkExpNegativeImageFilterIUC3IUC3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkExpNegativeImageFilterIUC3IUC3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkExpNegativeImageFilterIUC3IUC3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkExpNegativeImageFilterIUC3IUC3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkExpNegativeImageFilterIUC3IUC3_Superclass in _itkExpNegativeImageFilterPython:
_itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC3IUC3_Superclass_swigregister(itkExpNegativeImageFilterIUC3IUC3_Superclass)

def itkExpNegativeImageFilterIF2IF2_New():
    return itkExpNegativeImageFilterIF2IF2.New()

class itkExpNegativeImageFilterIF2IF2(itkExpNegativeImageFilterIF2IF2_Superclass):
    r"""Proxy of C++ itkExpNegativeImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkExpNegativeImageFilterIF2IF2_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkExpNegativeImageFilterIF2IF2_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF2IF2_Clone(self)

    def SetFactor(self, factor):
        r"""
        SetFactor(self, factor)

        Parameters
        ----------
        factor: double

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF2IF2_SetFactor(self, factor)

    def GetFactor(self):
        r"""GetFactor(self) -> double"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF2IF2_GetFactor(self)
    InputConvertibleToDoubleCheck = _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF2IF2_InputConvertibleToDoubleCheck
    
    DoubleConvertibleToOutputCheck = _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF2IF2_DoubleConvertibleToOutputCheck
    
    __swig_destroy__ = _itkExpNegativeImageFilterPython.delete_itkExpNegativeImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkExpNegativeImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkExpNegativeImageFilterIF2IF2

        Create a new object of the class itkExpNegativeImageFilterIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkExpNegativeImageFilterIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkExpNegativeImageFilterIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkExpNegativeImageFilterIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkExpNegativeImageFilterIF2IF2 in _itkExpNegativeImageFilterPython:
_itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF2IF2_swigregister(itkExpNegativeImageFilterIF2IF2)

def itkExpNegativeImageFilterIF3IF3_New():
    return itkExpNegativeImageFilterIF3IF3.New()

class itkExpNegativeImageFilterIF3IF3(itkExpNegativeImageFilterIF3IF3_Superclass):
    r"""Proxy of C++ itkExpNegativeImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkExpNegativeImageFilterIF3IF3_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkExpNegativeImageFilterIF3IF3_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF3IF3_Clone(self)

    def SetFactor(self, factor):
        r"""
        SetFactor(self, factor)

        Parameters
        ----------
        factor: double

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF3IF3_SetFactor(self, factor)

    def GetFactor(self):
        r"""GetFactor(self) -> double"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF3IF3_GetFactor(self)
    InputConvertibleToDoubleCheck = _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF3IF3_InputConvertibleToDoubleCheck
    
    DoubleConvertibleToOutputCheck = _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF3IF3_DoubleConvertibleToOutputCheck
    
    __swig_destroy__ = _itkExpNegativeImageFilterPython.delete_itkExpNegativeImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkExpNegativeImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkExpNegativeImageFilterIF3IF3

        Create a new object of the class itkExpNegativeImageFilterIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkExpNegativeImageFilterIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkExpNegativeImageFilterIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkExpNegativeImageFilterIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkExpNegativeImageFilterIF3IF3 in _itkExpNegativeImageFilterPython:
_itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIF3IF3_swigregister(itkExpNegativeImageFilterIF3IF3)

def itkExpNegativeImageFilterISS2ISS2_New():
    return itkExpNegativeImageFilterISS2ISS2.New()

class itkExpNegativeImageFilterISS2ISS2(itkExpNegativeImageFilterISS2ISS2_Superclass):
    r"""Proxy of C++ itkExpNegativeImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkExpNegativeImageFilterISS2ISS2_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkExpNegativeImageFilterISS2ISS2_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS2ISS2_Clone(self)

    def SetFactor(self, factor):
        r"""
        SetFactor(self, factor)

        Parameters
        ----------
        factor: double

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS2ISS2_SetFactor(self, factor)

    def GetFactor(self):
        r"""GetFactor(self) -> double"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS2ISS2_GetFactor(self)
    InputConvertibleToDoubleCheck = _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS2ISS2_InputConvertibleToDoubleCheck
    
    DoubleConvertibleToOutputCheck = _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS2ISS2_DoubleConvertibleToOutputCheck
    
    __swig_destroy__ = _itkExpNegativeImageFilterPython.delete_itkExpNegativeImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkExpNegativeImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkExpNegativeImageFilterISS2ISS2

        Create a new object of the class itkExpNegativeImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkExpNegativeImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkExpNegativeImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkExpNegativeImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkExpNegativeImageFilterISS2ISS2 in _itkExpNegativeImageFilterPython:
_itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS2ISS2_swigregister(itkExpNegativeImageFilterISS2ISS2)

def itkExpNegativeImageFilterISS3ISS3_New():
    return itkExpNegativeImageFilterISS3ISS3.New()

class itkExpNegativeImageFilterISS3ISS3(itkExpNegativeImageFilterISS3ISS3_Superclass):
    r"""Proxy of C++ itkExpNegativeImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkExpNegativeImageFilterISS3ISS3_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkExpNegativeImageFilterISS3ISS3_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS3ISS3_Clone(self)

    def SetFactor(self, factor):
        r"""
        SetFactor(self, factor)

        Parameters
        ----------
        factor: double

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS3ISS3_SetFactor(self, factor)

    def GetFactor(self):
        r"""GetFactor(self) -> double"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS3ISS3_GetFactor(self)
    InputConvertibleToDoubleCheck = _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS3ISS3_InputConvertibleToDoubleCheck
    
    DoubleConvertibleToOutputCheck = _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS3ISS3_DoubleConvertibleToOutputCheck
    
    __swig_destroy__ = _itkExpNegativeImageFilterPython.delete_itkExpNegativeImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkExpNegativeImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkExpNegativeImageFilterISS3ISS3

        Create a new object of the class itkExpNegativeImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkExpNegativeImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkExpNegativeImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkExpNegativeImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkExpNegativeImageFilterISS3ISS3 in _itkExpNegativeImageFilterPython:
_itkExpNegativeImageFilterPython.itkExpNegativeImageFilterISS3ISS3_swigregister(itkExpNegativeImageFilterISS3ISS3)

def itkExpNegativeImageFilterIUC2IUC2_New():
    return itkExpNegativeImageFilterIUC2IUC2.New()

class itkExpNegativeImageFilterIUC2IUC2(itkExpNegativeImageFilterIUC2IUC2_Superclass):
    r"""Proxy of C++ itkExpNegativeImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkExpNegativeImageFilterIUC2IUC2_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkExpNegativeImageFilterIUC2IUC2_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC2IUC2_Clone(self)

    def SetFactor(self, factor):
        r"""
        SetFactor(self, factor)

        Parameters
        ----------
        factor: double

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC2IUC2_SetFactor(self, factor)

    def GetFactor(self):
        r"""GetFactor(self) -> double"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC2IUC2_GetFactor(self)
    InputConvertibleToDoubleCheck = _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC2IUC2_InputConvertibleToDoubleCheck
    
    DoubleConvertibleToOutputCheck = _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC2IUC2_DoubleConvertibleToOutputCheck
    
    __swig_destroy__ = _itkExpNegativeImageFilterPython.delete_itkExpNegativeImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkExpNegativeImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkExpNegativeImageFilterIUC2IUC2

        Create a new object of the class itkExpNegativeImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkExpNegativeImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkExpNegativeImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkExpNegativeImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkExpNegativeImageFilterIUC2IUC2 in _itkExpNegativeImageFilterPython:
_itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC2IUC2_swigregister(itkExpNegativeImageFilterIUC2IUC2)

def itkExpNegativeImageFilterIUC3IUC3_New():
    return itkExpNegativeImageFilterIUC3IUC3.New()

class itkExpNegativeImageFilterIUC3IUC3(itkExpNegativeImageFilterIUC3IUC3_Superclass):
    r"""Proxy of C++ itkExpNegativeImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkExpNegativeImageFilterIUC3IUC3_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkExpNegativeImageFilterIUC3IUC3_Pointer"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC3IUC3_Clone(self)

    def SetFactor(self, factor):
        r"""
        SetFactor(self, factor)

        Parameters
        ----------
        factor: double

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC3IUC3_SetFactor(self, factor)

    def GetFactor(self):
        r"""GetFactor(self) -> double"""
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC3IUC3_GetFactor(self)
    InputConvertibleToDoubleCheck = _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC3IUC3_InputConvertibleToDoubleCheck
    
    DoubleConvertibleToOutputCheck = _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC3IUC3_DoubleConvertibleToOutputCheck
    
    __swig_destroy__ = _itkExpNegativeImageFilterPython.delete_itkExpNegativeImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkExpNegativeImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkExpNegativeImageFilterIUC3IUC3

        Create a new object of the class itkExpNegativeImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkExpNegativeImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkExpNegativeImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkExpNegativeImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkExpNegativeImageFilterIUC3IUC3 in _itkExpNegativeImageFilterPython:
_itkExpNegativeImageFilterPython.itkExpNegativeImageFilterIUC3IUC3_swigregister(itkExpNegativeImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def unary_functor_image_filter(*args: itkt.ImageLike,  functor=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for UnaryFunctorImageFilter"""
    import itk

    kwarg_typehints = { 'functor':functor }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.UnaryFunctorImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def unary_functor_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageIntensity.UnaryFunctorImageFilter
    unary_functor_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    unary_functor_image_filter.__doc__ = filter_object.__doc__

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def exp_negative_image_filter(*args: itkt.ImageLike,  factor: float=..., functor=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for ExpNegativeImageFilter"""
    import itk

    kwarg_typehints = { 'factor':factor,'functor':functor }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.ExpNegativeImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def exp_negative_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageIntensity.ExpNegativeImageFilter
    exp_negative_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    exp_negative_image_filter.__doc__ = filter_object.__doc__



